==> kubernetes-model-gatewayapi-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/UDPRouteSpecFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface UDPRouteSpecFluent<A extends UDPRouteSpecFluent<A>> extends Fluent<A>{
  public A addToParentRefs(Integer index,ParentReference item);
  public A setToParentRefs(Integer index,ParentReference item);
  public A addToParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.ParentReference... items);
  public A addAllToParentRefs(Collection<ParentReference> items);
  public A removeFromParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.ParentReference... items);
  public A removeAllFromParentRefs(Collection<ParentReference> items);
  public A removeMatchingFromParentRefs(Predicate<ParentReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParentRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParentReference> getParentRefs();
  public List<ParentReference> buildParentRefs();
  public ParentReference buildParentRef(Integer index);
  public ParentReference buildFirstParentRef();
  public ParentReference buildLastParentRef();
  public ParentReference buildMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public Boolean hasMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A withParentRefs(List<ParentReference> parentRefs);
  public A withParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.ParentReference... parentRefs);
  public Boolean hasParentRefs();
  public UDPRouteSpecFluent.ParentRefsNested<A> addNewParentRef();
  public UDPRouteSpecFluent.ParentRefsNested<A> addNewParentRefLike(ParentReference item);
  public UDPRouteSpecFluent.ParentRefsNested<A> setNewParentRefLike(Integer index,ParentReference item);
  public UDPRouteSpecFluent.ParentRefsNested<A> editParentRef(Integer index);
  public UDPRouteSpecFluent.ParentRefsNested<A> editFirstParentRef();
  public UDPRouteSpecFluent.ParentRefsNested<A> editLastParentRef();
  public UDPRouteSpecFluent.ParentRefsNested<A> editMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A addToRules(Integer index,UDPRouteRule item);
  public A setToRules(Integer index,UDPRouteRule item);
  public A addToRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.UDPRouteRule... items);
  public A addAllToRules(Collection<UDPRouteRule> items);
  public A removeFromRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.UDPRouteRule... items);
  public A removeAllFromRules(Collection<UDPRouteRule> items);
  public A removeMatchingFromRules(Predicate<UDPRouteRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<UDPRouteRule> getRules();
  public List<UDPRouteRule> buildRules();
  public UDPRouteRule buildRule(Integer index);
  public UDPRouteRule buildFirstRule();
  public UDPRouteRule buildLastRule();
  public UDPRouteRule buildMatchingRule(Predicate<UDPRouteRuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<UDPRouteRuleBuilder> predicate);
  public A withRules(List<UDPRouteRule> rules);
  public A withRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.UDPRouteRule... rules);
  public Boolean hasRules();
  public UDPRouteSpecFluent.RulesNested<A> addNewRule();
  public UDPRouteSpecFluent.RulesNested<A> addNewRuleLike(UDPRouteRule item);
  public UDPRouteSpecFluent.RulesNested<A> setNewRuleLike(Integer index,UDPRouteRule item);
  public UDPRouteSpecFluent.RulesNested<A> editRule(Integer index);
  public UDPRouteSpecFluent.RulesNested<A> editFirstRule();
  public UDPRouteSpecFluent.RulesNested<A> editLastRule();
  public UDPRouteSpecFluent.RulesNested<A> editMatchingRule(Predicate<UDPRouteRuleBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentRefsNested<N> extends Nested<N>,ParentReferenceFluent<UDPRouteSpecFluent.ParentRefsNested<N>>{
    public N and();
    public N endParentRef();
    
  }
  public interface RulesNested<N> extends Nested<N>,UDPRouteRuleFluent<UDPRouteSpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/UDPRouteSpecFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReferenceBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReferenceFluent;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface UDPRouteSpecFluent<A extends UDPRouteSpecFluent<A>> extends Fluent<A>{
  public A addToParentRefs(Integer index,ParentReference item);
  public A setToParentRefs(Integer index,ParentReference item);
  public A addToParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... items);
  public A addAllToParentRefs(Collection<ParentReference> items);
  public A removeFromParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... items);
  public A removeAllFromParentRefs(Collection<ParentReference> items);
  public A removeMatchingFromParentRefs(Predicate<ParentReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParentRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParentReference> getParentRefs();
  public List<ParentReference> buildParentRefs();
  public ParentReference buildParentRef(Integer index);
  public ParentReference buildFirstParentRef();
  public ParentReference buildLastParentRef();
  public ParentReference buildMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public Boolean hasMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A withParentRefs(List<ParentReference> parentRefs);
  public A withParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... parentRefs);
  public Boolean hasParentRefs();
  public UDPRouteSpecFluent.ParentRefsNested<A> addNewParentRef();
  public UDPRouteSpecFluent.ParentRefsNested<A> addNewParentRefLike(ParentReference item);
  public UDPRouteSpecFluent.ParentRefsNested<A> setNewParentRefLike(Integer index,ParentReference item);
  public UDPRouteSpecFluent.ParentRefsNested<A> editParentRef(Integer index);
  public UDPRouteSpecFluent.ParentRefsNested<A> editFirstParentRef();
  public UDPRouteSpecFluent.ParentRefsNested<A> editLastParentRef();
  public UDPRouteSpecFluent.ParentRefsNested<A> editMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A addToRules(Integer index,UDPRouteRule item);
  public A setToRules(Integer index,UDPRouteRule item);
  public A addToRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.UDPRouteRule... items);
  public A addAllToRules(Collection<UDPRouteRule> items);
  public A removeFromRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.UDPRouteRule... items);
  public A removeAllFromRules(Collection<UDPRouteRule> items);
  public A removeMatchingFromRules(Predicate<UDPRouteRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<UDPRouteRule> getRules();
  public List<UDPRouteRule> buildRules();
  public UDPRouteRule buildRule(Integer index);
  public UDPRouteRule buildFirstRule();
  public UDPRouteRule buildLastRule();
  public UDPRouteRule buildMatchingRule(Predicate<UDPRouteRuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<UDPRouteRuleBuilder> predicate);
  public A withRules(List<UDPRouteRule> rules);
  public A withRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.UDPRouteRule... rules);
  public Boolean hasRules();
  public UDPRouteSpecFluent.RulesNested<A> addNewRule();
  public UDPRouteSpecFluent.RulesNested<A> addNewRuleLike(UDPRouteRule item);
  public UDPRouteSpecFluent.RulesNested<A> setNewRuleLike(Integer index,UDPRouteRule item);
  public UDPRouteSpecFluent.RulesNested<A> editRule(Integer index);
  public UDPRouteSpecFluent.RulesNested<A> editFirstRule();
  public UDPRouteSpecFluent.RulesNested<A> editLastRule();
  public UDPRouteSpecFluent.RulesNested<A> editMatchingRule(Predicate<UDPRouteRuleBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentRefsNested<N> extends Nested<N>,ParentReferenceFluent<UDPRouteSpecFluent.ParentRefsNested<N>>{
    public N and();
    public N endParentRef();
    
  }
  public interface RulesNested<N> extends Nested<N>,UDPRouteRuleFluent<UDPRouteSpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}
